import scrapy, re

'''
scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=9 -a day=28
'''


TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
	return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
	title = scrapy.Field()
	text = scrapy.Field()
	date = scrapy.Field()
	location = scrapy.Field()
	author = scrapy.Field()
	topic = scrapy.Field()
	url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"
	
	def start_requests(self):
		year = getattr(self, 'year', None)
		month = getattr(self, 'month', None)
		day = getattr(self, 'day', None)
		
		self.baseURL='https://www.razon.com.mx/'+year+'/'+month+'/'+day
		
		yield scrapy.Request(url=self.baseURL, callback=self.parse)


	def parse(self, response):
		pagination = response.xpath('//*[@class="page-nav td-pb-padding-side"]/a[@class="last"]/@href').extract_first()
		pagination = pagination.strip('/')
		pages = int(pagination[pagination.rfind('/')+1:])

		for page in range(0,pages):
			if page == 0:
				yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
			else:
				yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)


	def parse_page(self, response):
		for link in response.xpath('//*[@class="td_module_1 td_module_wrap td-animation-stack"]/h3[@class="entry-title td-module-title"]/a/@href').extract():
			yield scrapy.Request(url=link, callback=self.parse_item)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		
		d = response.xpath('//span[@class="td-post-date td-post-date-no-dot"]/time/@datetime').extract_first()
		## '-06:00' corresponde al UTC-6, zona horaria del centro de mexico
		if d[-6:] != '-06:00':
			d = d[:-6] + '-06:00'
		item['date'] = d

		item['topic'] = response.xpath('//*[@class="entry-crumbs"]/span/a[@class="entry-crumb"]/text()').extract()[2]
		ti = response.xpath('//*[@class="td-post-header"]/header/h1/text()').extract_first()
		if ti is None:
			ti = response.xpath('//header[@class="td-post-title"]/h1/text()').extract_first()
		item['title'] = ti

		paragraphs = response.xpath('//*[@class="td-post-content"]/p').extract()
		if len(paragraphs) <= 0:
			paragraphs = response.xpath('//*[@dir="auto"]').extract()
		for p in paragraphs:
			text += remove_tags(p) + '\n'
		
		item['text'] = text
		item['url'] = response.url
		
		# print item['title']
		yield item

