import scrapy, re

'''
scrapy crawl noticias -t json --nolog -o noticias.json
'''

TAG_RE = re.compile(r'<[^>]+>')

def remove_tags(text):
    return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.baseURL = 'http://www.eluniversal.com.mx/rss.xml'
        yield scrapy.Request(url=self.baseURL, callback=self.parse)

    def parse(self, response):
        for link in response.xpath('//link/text()').extract()[1:]:
            yield scrapy.Request(url=link, callback=self.parse_item)

    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        item['topic'] = response.xpath('//*[@class="breadcrumb"]/span/a/text()').extract()[-2]
        item['title'] = response.xpath('//*[@class="pane-content"]/h1/text()').extract_first()
        paragraphs = response.xpath('//*[@class="pane-content"]/div/p').extract()
        paragraphs.extend(response.xpath('//*[@class="rtejustify"]').extract())
        for p in paragraphs:
            text += remove_tags(p) + '\n'
        item['text'] = text
        item['location'] = response.xpath('//*[@class="field field-name-field-lugar field-type-text field-label-hidden"]/text()').extract_first()
        item['author'] = response.xpath('//*[@class="field-items"]/div/text()').extract_first()
        item['url'] = response.url

        # print item['title']
        yield item

